@@ -6,20 +6,20 @@
 #  All right reserved.
 #  Email: geliudie@uni-duesseldorf.de
 #  
-#  This file is part of SyBiL.
+#  This file is part of sybil.
 #
-#  SyBiL is free software: you can redistribute it and/or modify
+#  sybil is free software: you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
 #  the Free Software Foundation, either version 3 of the License, or
 #  (at your option) any later version.
 #
-#  SyBiL is distributed in the hope that it will be useful,
+#  sybil is distributed in the hope that it will be useful,
 #  but WITHOUT ANY WARRANTY; without even the implied warranty of
 #  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #  GNU General Public License for more details.
 #
 #  You should have received a copy of the GNU General Public License
-#  along with SyBiL.  If not, see <http://www.gnu.org/licenses/>.
+#  along with sybil.  If not, see <http://www.gnu.org/licenses/>.
 
 
 ################################################
@@ -28,24 +28,10 @@
 # This function performs a "double gene deletion analysis".
 # In each iteration one gene is switched of (vi = 0)
 # and the objective function will be computed.
-#
-# Parameters:
-#      model:   an object of class modelorg
-#     solver:   lp problem solver (glpk [default], lpSolve)
-#     method:   simplex[default], interior
-#     fluxdist: boolean, TRUE: get the flux distribution.
-#               FALSE [default] is recommended
-#
-#        ...:   further arguments, passed to optimizer()
-#
-# Returns an object of class optsol_genedel.
 
 
-doubleFluxDel <- function(model, react1, react2, allComb = FALSE,
-                          lpdir = SYBIL_SETTINGS("OPT_DIRECTION"),
-                          solver = SYBIL_SETTINGS("SOLVER"),
-                          method = SYBIL_SETTINGS("METHOD"),
-                          fld = FALSE, exex = FALSE, ...) {
+doubleFluxDel <- function(model, react1, react2,
+                          allComb = FALSE, exex = FALSE, ...) {
 
     if (!is(model, "modelorg")) {
         stop("needs an object of class modelorg!")
@@ -108,11 +94,14 @@ doubleFluxDel <- function(model, react1, react2, allComb = FALSE,
   
     if (isTRUE(allComb)) {
 
-        # Compute boolean matrix with TRUE in the upper triangonal (the maximum number of comparisons)
-        tmpMAT <- upper.tri(matrix(nrow = react_num(model), ncol = react_num(model)))
+        # Compute boolean matrix with TRUE in the upper triangonal
+        # (the maximum number of comparisons)
+        tmpMAT <- upper.tri(matrix(nrow = react_num(model),
+                                   ncol = react_num(model)))
     
-        # The next step is, to compute the differences between the two fields. If an element of react1 is
-        # not in react2, we have to set the corresponding row to TRUE and vice versa.
+        # The next step is, to compute the differences between the two fields.
+        # If an element of react1 is not in react2, we have to set the
+        # corresponding row to TRUE and vice versa.
         tmpDIFF <- setdiff(react2, react1)
         # print(tmpDIFF)
     
@@ -143,7 +132,8 @@ doubleFluxDel <- function(model, react1, react2, allComb = FALSE,
     }
     else {
   
-        tmpMAT <- matrix(FALSE, nrow = react_num(model), ncol = react_num(model))
+        tmpMAT <- matrix(FALSE, nrow = react_num(model),
+                                ncol = react_num(model))
         for (i in 1:num_react1) {
             tmpMAT[react1[i], react2[i]] <- TRUE
         }
@@ -165,34 +155,13 @@ doubleFluxDel <- function(model, react1, react2, allComb = FALSE,
 #                               run optimization                               #
 #------------------------------------------------------------------------------#
   
-    # new object for the solution
-    optsol <- optsol_doublefluxdel(solver  = solver,
-                                   nprob   = num_opt,
-                                   lpdir   = lpdir,
-                                   nrows   = met_num(model),
-                                   ncols   = react_num(model),
-                                   delrows = nrow(tmpMAT),
-                                   delcols = ncol(tmpMAT),
-                                   objf    = printObjFunc(model),
-                                   fld     = fld
-                                  )
-
-
     deletions <- which(tmpMAT == TRUE, arr.ind = TRUE)
-  
-    react_id(optsol) <- react_id(model)
-    allGenes(optsol) <- allGenes(model)
-    method(optsol) <- method
-
-    # indices of genes to delete
-    dels(optsol)[-1,] <- cbind(react1[deletions[,"row"]], react2[deletions[,"col"]])
-    delmat(optsol) <- tmpMAT
-
-#print(dels(optsol))
-#print(delmat(optsol))
-#print(num_opt)
-
-    optsol <- optimizer(model = model, optsol = optsol, ...)
+    
+    optsol <- optimizer(model = model,
+                        delete = cbind(react1[deletions[,"row"]],
+                                       react2[deletions[,"col"]]),
+                        geneFlag = FALSE,
+                        ...)
 
     return(optsol)
 
