@@ -6,20 +6,20 @@
 #  All right reserved.
 #  Email: geliudie@uni-duesseldorf.de
 #
-#  This file is part of SyBiL.
+#  This file is part of sybil.
 #
-#  SyBiL is free software: you can redistribute it and/or modify
+#  sybil is free software: you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
 #  the Free Software Foundation, either version 3 of the License, or
 #  (at your option) any later version.
 #
-#  SyBiL is distributed in the hope that it will be useful,
+#  sybil is distributed in the hope that it will be useful,
 #  but WITHOUT ANY WARRANTY; without even the implied warranty of
 #  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #  GNU General Public License for more details.
 #
 #  You should have received a copy of the GNU General Public License
-#  along with SyBiL.  If not, see <http://www.gnu.org/licenses/>.
+#  along with sybil.  If not, see <http://www.gnu.org/licenses/>.
 
 
 # optsolClass
@@ -31,8 +31,10 @@
 
 setClass("optsol",
     representation(
+        mod_id       = "character",        # model id of the original model
         solver       = "character",        # the used lp solver
         method       = "character",        # the used method
+        algorithm    = "character",        # the used algorithm
         num_of_prob  = "integer",          # number of problems to solve
         lp_num_cols  = "integer",          # number of reactions
         lp_num_rows  = "integer",          # number of metabolites
@@ -40,10 +42,12 @@ setClass("optsol",
         lp_ok        = "integer",          # exit status of the lp solver
         lp_stat      = "integer",          # solution status
         lp_dir       = "character",        # direction
-        obj_function = "character",        # the objective function
+        obj_coef     = "numeric",          # objective coefficients in model
+        fldind       = "integer",          # indices of fluxes
         fluxdist     = "fluxDistribution"  # the flux distribution
     ),
-    validity = sybil:::.validoptsol
+    contains = "VIRTUAL",
+    #validity = sybil:::.validoptsol
 )
 
 
@@ -64,6 +68,21 @@ optsol <- function(solver) {
 #                            setters and getters                               #
 #------------------------------------------------------------------------------#
 
+# mod_id
+setMethod("mod_id", signature(object = "optsol"),
+          function(object) {
+              return(object@mod_id)
+          }
+)
+
+setReplaceMethod("mod_id", signature = (object = "optsol"),
+                 function(object, value) {
+                     object@mod_id <- value
+                     return(object)
+                 }
+)
+
+
 # solver
 setMethod("solver", signature(object = "optsol"),
           function(object) {
@@ -94,6 +113,21 @@ setReplaceMethod("method", signature = (object = "optsol"),
 )
 
 
+# method
+setMethod("algorithm", signature(object = "optsol"),
+          function(object) {
+              return(object@algorithm)
+          }
+)
+
+setReplaceMethod("algorithm", signature = (object = "optsol"),
+                 function(object, value) {
+                     object@algorithm <- value
+                     return(object)
+                 }
+)
+
+
 # num_of_prob
 setMethod("num_of_prob", signature(object = "optsol"),
           function(object) {
@@ -199,16 +233,31 @@ setReplaceMethod("lp_stat", signature = (object = "optsol"),
 )
 
 
-# obj_function
-setMethod("obj_function", signature(object = "optsol"),
+# objective coefficient
+setMethod("obj_coef", signature(object = "optsol"),
           function(object) {
-              return(object@obj_function)
+              return(object@obj_coef)
           }
 )
 
-setReplaceMethod("obj_function", signature = (object = "optsol"),
+setReplaceMethod("obj_coef", signature(object = "optsol"),
+          function(object, value) {
+              object@obj_coef <- value
+              return(object)
+          }
+)
+
+
+# fldind
+setMethod("fldind", signature(object = "optsol"),
+          function(object) {
+              return(object@fldind)
+          }
+)
+
+setReplaceMethod("fldind", signature = (object = "optsol"),
                  function(object, value) {
-                     object@obj_function <- value
+                     object@fldind <- value
                      return(object)
                  }
 )
@@ -270,12 +319,10 @@ setMethod("show", signature(object = "optsol"),
     function(object) {
         
         cat("solver:                                  ", solver(object), "\n")
-        cat("method:                                  ", paste(unique(method(object)), collapse = " and "), "\n")
-        if ("algorithm" %in% slotNames(object)) {
-            cat("algorithm:                               ", algorithm(object), "\n")
-        }
-        cat("number of reactions:                     ", lp_num_cols(object), "\n")
-        cat("number of metabolites:                   ", lp_num_rows(object), "\n")
+        cat("method:                                  ", method(object), "\n")
+        cat("algorithm:                               ", algorithm(object), "\n")
+        cat("number of variables:                     ", lp_num_cols(object), "\n")
+        cat("number of constraints:                   ", lp_num_rows(object), "\n")
         cat("number of problems to solve:             ", num_of_prob(object), "\n")
         ok <- sum(lp_ok(object) == 0, na.rm = TRUE)
         cat("number of successful solution processes: ", ok, "\n")
@@ -291,16 +338,15 @@ setMethod("length", signature = signature(x = "optsol"),
 )
 
 
-# draw a histogramm (check for lattice!)
-setMethod("hist", signature(x = "optsol"),
+# draw a histogramm (package lattice)
+setMethod("histogram", signature(x = "optsol"),
           function(x,
                    main = "",
-                   xlab = obj_function(x),
-                   col = "blue",
+                   xlab = "value of objective function",
                    ...) {
 
 
-              hist(lp_obj(x), main = main, xlab = xlab, col = col, ...)
+              histogram(lp_obj(x), main = main, xlab = xlab, ...)
               
           }
 )
