@@ -6,20 +6,20 @@
 #  All right reserved.
 #  Email: geliudie@uni-duesseldorf.de
 #  
-#  This file is part of SyBiL.
+#  This file is part of sybil.
 #
-#  SyBiL is free software: you can redistribute it and/or modify
+#  sybil is free software: you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
 #  the Free Software Foundation, either version 3 of the License, or
 #  (at your option) any later version.
 #
-#  SyBiL is distributed in the hope that it will be useful,
+#  sybil is distributed in the hope that it will be useful,
 #  but WITHOUT ANY WARRANTY; without even the implied warranty of
 #  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #  GNU General Public License for more details.
 #
 #  You should have received a copy of the GNU General Public License
-#  along with SyBiL.  If not, see <http://www.gnu.org/licenses/>.
+#  along with sybil.  If not, see <http://www.gnu.org/licenses/>.
 
 
 # optsol_blockedReactClass
@@ -39,44 +39,6 @@ setClass("optsol_blockedReact",
 )
 
 
-#------------------------------------------------------------------------------#
-#                              user constructor                                #
-#------------------------------------------------------------------------------#
-
-optsol_blockedReact <- function(solver, nprob, ncols, nrows, fld) {
-    if (missing(solver) ||
-        missing(nprob)  ||
-        missing(ncols)  ||
-        missing(nrows)  ||
-        missing(fld)
-       ) {
-        stop("Not enough arguments for creating an object of class optsol_blockedReact!")
-    }
-
-    if (fld == TRUE) {
-        fldist <- fluxDistribution(0, (ncols * 2), nprob)
-    }
-    else {
-        fldist <- fluxDistribution(NA)
-    }
-
-    new("optsol_blockedReact",
-        solver       = as.character(solver),
-        num_of_prob  = as.integer(nprob),
-        lp_num_cols  = as.integer(ncols),
-        lp_num_rows  = as.integer(nrows),
-        lp_obj       = numeric(nprob),
-        lp_ok        = integer(nprob),
-        lp_stat      = integer(nprob),
-        lp_dir       = "max/min",
-        obj_function = "identify blocked reactions",
-        fluxdist     = fldist,
-        blocked      = logical(ncols)
-       )
-
-}
-
-
 #------------------------------------------------------------------------------#
 #                            setters and getters                               #
 #------------------------------------------------------------------------------#
