@@ -6,20 +6,20 @@
 #  All right reserved.
 #  Email: geliudie@uni-duesseldorf.de
 #
-#  This file is part of SyBiL.
+#  This file is part of sybil.
 #
-#  SyBiL is free software: you can redistribute it and/or modify
+#  sybil is free software: you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
 #  the Free Software Foundation, either version 3 of the License, or
 #  (at your option) any later version.
 #
-#  SyBiL is distributed in the hope that it will be useful,
+#  sybil is distributed in the hope that it will be useful,
 #  but WITHOUT ANY WARRANTY; without even the implied warranty of
 #  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #  GNU General Public License for more details.
 #
 #  You should have received a copy of the GNU General Public License
-#  along with SyBiL.  If not, see <http://www.gnu.org/licenses/>.
+#  along with sybil.  If not, see <http://www.gnu.org/licenses/>.
 
 
 ################################################
@@ -43,6 +43,7 @@ readTSVmod <- function(prefix, suffix,
                        tol = SYBIL_SETTINGS("TOLERANCE"),
                        fpath = SYBIL_SETTINGS("PATH_TO_MODEL"),
                        def_bnd = SYBIL_SETTINGS("MAXIMUM"),
+                       arrowlength = NULL,
                        quoteChar = "",
                        commentChar = "",
                        ...) {
@@ -103,6 +104,21 @@ readTSVmod <- function(prefix, suffix,
     # regular expression to identify external metabolites
     extMetRegEx <- paste("\\[", extMetFlag, "\\]$", sep = "")
 
+    
+    # regular expression to identify the reaction arrow
+    if (is.null(arrowlength)) {
+        arrowregex <- "<?[-=]+>"
+    }
+    else {
+        stopifnot(length(arrowlength) == 1)
+        if (is.numeric(arrowlength)) {
+            arrowregex <- paste("<?[-=]{", arrowlength, "}>", sep = "")
+        }
+        else if (is.character(arrowlength)) {
+            arrowregex <- paste("<?[-=]", arrowlength, ">", sep = "")
+        }
+    }
+
 
     #--------------------------------------------------------------------------#
     # some functions
@@ -573,7 +589,7 @@ readTSVmod <- function(prefix, suffix,
         # Reversible reactions can begin with a '<' sign.
 
         # get the position of the arrow symbol
-        arrowpos  <- gregexpr("<?[-=]+>", equat, perl = TRUE)[[1]]
+        arrowpos  <- gregexpr(arrowregex, equat, perl = TRUE)[[1]]
 
         if (length(arrowpos) > 1) {
             msg <- paste("more than one arrow symbols found, skipping",
